EventHandler

Trait EventHandler 

pub trait EventHandler: Send + Sync {
    // Required method
    fn handle_events(event: Event);
}
This is the bridge between system events and the lib events

Required Methods

fn handle_events(event: Event)

handle_events is the only function for the trait and it results a non blocking Event object

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors